# target_selection

![Versions](https://img.shields.io/badge/python->3.7-blue)
[![Documentation Status](https://readthedocs.org/projects/sdss-target-selection/badge/?version=latest)](https://sdss-target-selection.readthedocs.io/en/latest/?badge=latest)
<!-- [![Travis (.org)](https://img.shields.io/travis/sdss/target_selection)](https://travis-ci.org/sdss/target_selection)
[![codecov](https://codecov.io/gh/sdss/target_selection/branch/master/graph/badge.svg)](https://codecov.io/gh/sdss/target_selection) -->

Code to perform target selection for BHM/MWM using catalogdb.
